@@ -166,13 +166,13 @@ void TransformAction::perform() {
   }
 
   if (_product) {
-    auto_ptr<BigIdeal> ideal;
+    unique_ptr<BigIdeal> ideal;
     ideal.reset(new BigIdeal(names));
 
     idealFacade.takeProducts(ideals, *ideal);
 
     idealsDeleter.deleteElements();
-    exceptionSafePushBack(ideals, ideal);
+    exceptionSafePushBack(ideals, std::move(ideal));
   }
 
   for (size_t i = 0; i < ideals.size(); ++i) {
@@ -216,7 +216,7 @@ void TransformAction::perform() {
     sort(ideals.begin(), ideals.end(), compareIdeals);
   }
 
-  auto_ptr<IOHandler> output(_io.createOutputHandler());
+  unique_ptr<IOHandler> output(_io.createOutputHandler());
   facade.writeIdeals(ideals, names, output.get(), stdout);
 }
 
